#!/bin/ksh
###############################################################
#
# ifc.sh - collect misc lan card and interface info
# 
# -list		generate a list of interfaces
# -ip IF        show the ip of interface IF
# -ifc IF       generate an interfaces.cfg 
# -v            print all
#               print all IPs 
###############################################################

#set -x

LC_ALL=C
export LC_ALL

M="$1"
H=`uname`
V=`uname -r`
D="`dirname $0`"

if [ "$V" = "5.11" ]; then
   V="5.10"
fi


NETSTAT=/usr/bin/netstat
UNIQ="/bin/sort -u"
IFCONFIG=/usr/sbin/ifconfig

if [ "$H" = "HP-UX" ]; then
   AWK=awk
   LSDEV=/usr/sbin/lsdev
   LANSCAN=/usr/sbin/lanscan
elif [ "$H" = "SunOS" ]; then
   AWK=nawk
   MODINFO=/usr/sbin/modinfo
elif [ "$H" = "AIX" ]; then
   AWK=awk
   LSDEV=/usr/sbin/lsdev
   MODINFO=/usr/sbin/modinfo
   if [ "`uname -v`" = "4" ]; then
      H="AIX4"
   else
      H="AIX5"
   fi
elif [ "$H" = "Linux" ]; then
   IFCONFIG="/sbin/ifconfig"
fi

if [ "$M" = "-list" ]; then
    if [ "$H" = "HP-UX" ]; then
        HPVER=`uname -r | awk -F. '{printf "%d%02d",\$2,\$3}'`
	if test $HPVER -gt 1100
	then
		INTERFACES=`$NETSTAT -nr | awk '{print $5}' | grep -v Interface | sort -u`
	else
		INTERFACES=`$NETSTAT -nr | awk '{print $6}' | grep -v Interface | sort -u` 
	fi 
	
	   for ifc in $INTERFACES ; do
	   $IFCONFIG $ifc | grep LOOPBACK > /dev/null 2> /dev/null
            if [ $? -eq 1 ]; then
                echo "$ifc"
            fi
         done
    elif [ "$H" = "SunOS" ]; then
	if [ "$V" = "5.10" ]; then
	   for ifc in `$IFCONFIG -auZ | grep "flags=" | grep UP | cut -d' ' -f1 -s | \
              grep -v "lo0" | grep -v 0.0.0.0 | sort -u`; do
              echo "$ifc"
           done
	else
	   for ifc in `$IFCONFIG -au | grep "flags=" | grep UP | cut -d' ' -f1 -s | \
              grep -v "lo0" | grep -v 0.0.0.0 | sort -u`; do
              echo "$ifc"
           done
	fi
    elif [ "$H" = "AIX4" ]; then
        for ifc in `$NETSTAT -in | grep -v Mtu | grep -v ^lo | \
            grep -vi link |$AWK '{print $1}' | grep -v '*' | grep -v 0.0.0.0 | sort -u`; do
            echo "$ifc"
        done
    elif [ "$H" = "AIX5" ]; then
        for ifc in `$IFCONFIG -a | grep flags | grep UP | \
            grep -v ^lo|$AWK '{print $1}' | grep -v 0.0.0.0 | $UNIQ| tr -d ' '`; do
            echo "$ifc"
        done
    elif [ "$H" = "Linux" ]; then
		ifc=`$IFCONFIG |sed -ne "s/\(^.*[^ ]\) *Link encap.*/\1:/p" | grep -v 0.0.0.0 | grep -v "^lo[0-9]*"`
		if [ -z "$ifc" ]; then
			ifc=`$IFCONFIG | sed -ne "s/\(^.*[^ ]\) *flags.*/\1/p" | grep -v 0.0.0.0 | grep -v "^lo[0-9]*"`
		fi
		echo "$ifc"
    fi
elif [ "$M" = "-ip" ]; then
    ifc=`echo $2 | sed 's/:$//'`
	
    if [ "$H" = "Linux" ] ; then
    	ip_addr=`$IFCONFIG $ifc | sed -ne "s/.*inet addr:\(.*\..*\..*\..*\) *Bcast.*/\1/p" | grep -v 0.0.0.0`
		if [ -z "$ip_addr" ] ; then
			ip_addr=`$IFCONFIG $ifc | sed -ne "s/.*inet \(.*\..*\..*\..*\) * netmask.*/\1/p" | grep -v 0.0.0.0`
		fi
    else
	$IFCONFIG $ifc | grep UP > /dev/null 2> /dev/null
	if [ $? -eq 0 ]; then
            ip_addr=`$IFCONFIG $ifc | grep -v inet6 | grep "inet" | cut -d" " -f2 | grep -v 0.0.0.0`   
	else
	    ip_addr="NULL"
        fi 
    fi
    echo "$ip_addr"
elif [ "$1" = "-ifc" ]; then
    PORT_SAP_CODE=800
    interface=`echo $2|sed 's/:$//'`
    if [ "$H" = "HP-UX" ]; then
        ifc=`echo $interface | tr -d '[0-9]' | tr -d ':'`
         nm_id=`$LANSCAN | grep $interface | awk '{print $7}'`
        echo "ifc\t$ifc\t$PORT_SAP_CODE\t$nm_id"
    elif [ "$H" = "SunOS" ]; then
        ifc=`echo $interface | tr -d '[0-9]' | tr -d ':'`
        echo "ifc\t$ifc\t$PORT_SAP_CODE\t0"
    elif [ "$H" = "AIX4" ]; then
        ifc=`echo $interface | tr -d ':'`
        echo "ifc\t$ifc\t$PORT_SAP_CODE\t0"
    elif [ "$H" = "AIX5" ]; then
        ifc=`echo $interface | tr -d ':'`
        echo "ifc\t$ifc\t$PORT_SAP_CODE\t0"
    elif [ "$H" = "Linux" ]; then
        ifc=`echo $interface | tr -d '[0-9]'`
        echo "ifc\t$ifc\t$PORT_SAP_CODE\t0"
    fi
elif [ "$M" = "-v" ]; then
    for ifc in `$D/ifc.sh -list|sort -u` ; do
       ifc_ip=`$D/ifc.sh -ip $ifc|sort -u`
       if [ "$ifc_ip" != "NULL" ]; then
	   echo "Interface $ifc IP address $ifc_ip"
       else
           echo "Interface $ifc is DOWN"
       fi
    done
else
    for ifc in `$D/ifc.sh -list|sort -u` ; do
       ifc_ip=`$D/ifc.sh -ip $ifc|sort -u`
       if [ "$ifc_ip" != "NULL" -a  "$ifc_ip" != "" ]; then
	   echo "$ifc_ip"
       fi
    done
fi






